#ifndef _IFMAIL_CHARSET_H_
#define _IFMAIL_CHARSET_H_
#include "rfcmsg.h"

/* recognized charsets */
#define CHRS_AUTODETECT		-1
#define CHRS_NOTSET		 0
#define CHRS_ASCII		 1 /* us-ascii */
#define CHRS_BIG5		 2 /* Chinese Big5 charset */
#define CHRS_CP424		 3 /* hebrew EBCDIC */
#define CHRS_CP437		 4 /* Latin-1 MS codage (cp437) */
#define CHRS_CP852		 5 /* Polish MS-DOS codage */
#define CHRS_CP862		 6 /* Hebrew PC */
#define CHRS_CP866		 7 /* Cyrillic Alt-PC (cp866) */
#define CHRS_CP895		 8 /* Kamenicky (DOS charset in CZ & SK) */
#define CHRS_EUC_JP		 9 /* Japanese EUC */
#define CHRS_EUC_KR		10 /* Korean EUC */
#define CHRS_FIDOMAZOVIA	11 /* Polish "FIDOMAZOVIA" charset */
#define CHRS_GB			12 /* Chinese GB 2312 8 bits */
#define CHRS_HZ			13 /* Chinese HZ coding */
#define CHRS_ISO_2022_CN	14 /* Chinese GB 2312 7 bits */
#define CHRS_ISO_2022_JP	15 /* Japanese iso-2022-jp */
#define CHRS_ISO_2022_KR        16 /* Korean iso-2022-kr */
#define CHRS_ISO_2022_TW	17 /* Taiwanese iso-2022-tw */
#define CHRS_ISO_8859_1		18 /* Latin-1, Western Europe, America */ 
#define CHRS_ISO_8859_1_QP	19
#define CHRS_ISO_8859_2		20 /* Latin-2, Eastern Europe */
#define CHRS_ISO_8859_3		21 /* Latin-3, Balkanics languages */
#define CHRS_ISO_8859_4		22 /* Latin-4, Scandinavian, Baltic */
#define CHRS_ISO_8859_5		23 /* Cyrillic (iso-8859-5) */
#define CHRS_ISO_8859_6		24 /* Arabic (iso-8859-6) */
#define CHRS_ISO_8859_7		25 /* Greek (iso-8859-7) */
#define CHRS_ISO_8859_8		26 /* Hebrew (iso-8859-8) */
#define CHRS_ISO_8859_9		27 /* Latin-5, Turkish */
#define CHRS_ISO_8859_10	28 /* Latin-6, Lappish/Nordic/Eskimo */
#define CHRS_ISO_8859_11	29 /* Thai (iso-8859-11, aka TIS620) */
#define CHRS_KOI8_R		30 /* Cyrillic Koi8 (Russian) */
#define CHRS_KOI8_U		31 /* Cyrillic Koi8 (Ukranian) */
#define CHRS_MACINTOSH		32 /* Macintosh */
#define CHRS_MIK_CYR		33 /* Bulgarian "Mik" cyrillic charset */
#define CHRS_NEC		34 /* Japanese NEC-JIS charset */
#define CHRS_SJIS		35 /* Japanese Shift-JIS (MS codage) */
#define CHRS_UNICODE_1_1	36 /* Unicode-1-1 */
#define CHRS_ZW			37 /* Chinese Zw encoding */

#define CHRS_ISO_11             91
#define CHRS_ISO_4              92
#define CHRS_ISO_60             93

/* languages (used for LANG_DEFAULT definition) */
#define LANG_WEST		1 /* West-European languages */	
#define LANG_EAST		2 /* East-Eurpean languages */
#define LANG_JAPAN		3 /* japanese */
#define LANG_KOREA		4 /* korean */
#define LANG_CHINA		5 /* chinese */
#define LANG_CYRILLIC		6 /* Cyrillic based languages */

/* Define these according to the values used in your country */
#define CHRS_DEFAULT_FTN	CHRS_CP437
#define CHRS_DEFAULT_RFC	CHRS_ISO_8859_1
#define LANG_DEFAULT		LANG_WEST

#if (LANG_DEFAULT==LANG_JAPAN || LANG_DEFAULT==LANG_KOREA || LANG_DEFAULT==LANG_CHINA)
#define LANG_BITS	16
#else
#define LANG_BITS	8
#endif

/* used to recognize pgpsigned messages */
#define PGP_SIGNED_BEGIN	"-----BEGIN PGP SIGNED MESSAGE-----"
#define PGP_SIG_BEGIN		"-----BEGIN PGP SIGNATURE-----"
#define PGP_SIG_END		"-----END PGP SIGNATURE-----"

/* charset reading functions */
int getoutcode(int);
int getincode(int);
char *getcharset(int);
char *getchrs(int);
int getcode(char *);
int readchrs(char *);
int readcharset(char *);
void writechrs(int,FILE *,int);
void writecharset(int,FILE *,rfcmsg *,rfcmsg *);

#endif /* _IFMAIL_CHARSET_H_ */
